@@ -9,11 +9,12 @@ def create_from(schema: Union[dict, str, Path]):
     if isinstance(schema, Path):
         schema = json.loads(schema.read_text())
     elif isinstance(schema, str):
-        path = Path(schema)
-        if path.is_file():
-            schema = json.loads(path.read_text())
-        else:
+        try:
             schema = json.loads(schema)
+        except json.decoder.JSONDecodeError:
+            path = Path(schema)
+            if path.is_file():
+                schema = json.loads(path.read_text())
 
     obj = {}
     properties = schema.get("properties", {})
@@ -27,6 +28,8 @@ def _get_default(name: str, prop: dict, schema: dict):
     ref = prop.get("$ref")
     prop_type = prop.get("type", None)
     if not ref:
+        if isinstance(prop_type, list):
+            prop_type = prop_type[0]
         if prop_type not in __generators:
             raise RuntimeError(f"Property '{name}' has an invalid type: {prop_type}")
 
